@@ -5,15 +5,17 @@ use strict;
 use warnings;
 
 use Cwd qw(abs_path);
-use File::Trash::FreeDesktop;
-use Perinci::Sub::Gen::Undoable 0.13 qw(gen_undoable_func);
+use File::Trash::FreeDesktop 0.05;
+use Perinci::Sub::Gen::Undoable 0.14 qw(gen_undoable_func);
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 our %SPEC;
 
 my $trash = File::Trash::FreeDesktop->new;
 
+my $_step_untrash;
+
 my $res = gen_undoable_func(
     name => 'trash_files',
     summary => 'Trash files (with undo support)',
@@ -56,8 +58,9 @@ Argument is path (should be absolute).
 _
             check => sub {
                 my ($args, $step) = @_;
-                return [200, "OK", ["recover", $step->[1]]];
+                return [200, "OK", ["untrash", $step->[1]]];
             },
+            fix_log_message => "Trashing %(_step_arg0)s ...",
             fix => sub {
                 my ($args, $step, $undo) = @_;
                 my $a = $step->[1];
@@ -65,8 +68,8 @@ _
                 [200, "OK"];
             },
         },
-        recover => {
-            summary => 'Recover a file',
+        untrash => ($_step_untrash = {
+            summary => 'Untrash a file',
             description => <<'_',
 
 Argument is path.
@@ -76,13 +79,19 @@ _
                 my ($args, $step) = @_;
                 return [200, "OK", ["trash", $step->[1]]];
             },
+            fix_log_message => "Untrashing %(_step_arg0)s ...",
             fix => sub {
                 my ($args, $step, $undo) = @_;
                 my $a = $step->[1];
-                $trash->recover($a);
+                $trash->recover({
+                    on_not_found     => 'ignore',
+                    on_target_exists => 'ignore',
+                }, $a);
                 [200, "OK"];
             },
-        },
+        }),
+        # old alias to untrash
+        recover => $_step_untrash,
     },
 );
 $res->[0] == 200 or die "Can't generate function: $res->[0] - $res->[1]";
@@ -120,7 +129,7 @@ File::Trash::Undoable - Trash files (with undo support)
 
 =head1 VERSION
 
-version 0.01
+version 0.02
 
 =head1 SYNOPSIS
 
